summaryrefslogtreecommitdiffstats
path: root/security/nss/tests/all.sh
diff options
context:
space:
mode:
authorMoonchild <moonchild@palemoon.org>2020-12-23 19:02:52 +0000
committerMoonchild <moonchild@palemoon.org>2020-12-23 19:02:52 +0000
commit029bcfe189eae5eebbaf58ccff4e1200dd78b228 (patch)
tree1c226a334ea1a88e2d1c6f949c9320eb0c3bff59 /security/nss/tests/all.sh
parent149d2ffa779826cb48a381099858e76e4624d471 (diff)
downloadUXP-029bcfe189eae5eebbaf58ccff4e1200dd78b228.tar
UXP-029bcfe189eae5eebbaf58ccff4e1200dd78b228.tar.gz
UXP-029bcfe189eae5eebbaf58ccff4e1200dd78b228.tar.lz
UXP-029bcfe189eae5eebbaf58ccff4e1200dd78b228.tar.xz
UXP-029bcfe189eae5eebbaf58ccff4e1200dd78b228.zip
Issue #1693 - Update NSS to 3.59.1.1
This updates to MoonchildProductions/NSS@bd49b2b88 in the repo created for our consumption of the library.
Diffstat (limited to 'security/nss/tests/all.sh')
-rwxr-xr-xsecurity/nss/tests/all.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/security/nss/tests/all.sh b/security/nss/tests/all.sh
index aeda4e30d..99a7fd639 100755
--- a/security/nss/tests/all.sh
+++ b/security/nss/tests/all.sh
@@ -51,10 +51,10 @@
# pkix - run test suites with PKIX enabled
# upgradedb - upgrade existing certificate databases to shareable
# format (creates them if doesn't exist yet) and run
-# test suites with those databases
+# test suites with those databases. Requires to enable libdm.
# sharedb - run test suites with shareable database format
# enabled (databases are created directly to this
-# format)
+# format). This is the default and doesn't need to be run separately.
#
# Mandatory environment variables (to be set before testing):
# -----------------------------------------------------------
@@ -135,16 +135,16 @@ run_tests()
}
########################## run_cycle_standard ##########################
# run test suites with dbm database (no PKIX, no sharedb)
########################################################################
run_cycle_standard()
{
TEST_MODE=STANDARD
TESTS="${ALL_TESTS}"
- TESTS_SKIP="cipher libpkix sdr ocsp pkits"
+ TESTS_SKIP="libpkix pkits"
- NSS_DEFAULT_DB_TYPE="dbm"
+ NSS_DEFAULT_DB_TYPE=${NSS_DEFAULT_DB_TYPE:-"sql"}
export NSS_DEFAULT_DB_TYPE
run_tests
@@ -288,7 +288,7 @@ if [ -z "${INIT_SOURCED}" -o "${INIT_SOURCED}" != "TRUE" ]; then
. ./init.sh
fi
-cycles="standard pkix upgradedb sharedb"
+cycles="standard pkix"
CYCLES=${NSS_CYCLES:-$cycles}
NO_INIT_SUPPORT=`certutil --build-flags |grep -cw NSS_NO_INIT_SUPPORT`
@@ -135,16 +135,16 @@ run_tests()
}
########################## run_cycle_standard ##########################
-# run test suites with dbm database (no PKIX, no sharedb)
+# run test suites with sql database (no PKIX)
########################################################################
run_cycle_standard()